@@ -8,7 +8,6 @@ from dovado_rtl.src_parsing import SourceParser
 from dovado_rtl.vivado_interaction import get_parts
 from dovado_rtl.antlr.hdl_representation import PortDirectionEnum
 from dovado_rtl.simple_types import Metric
-from dovado_rtl.enums import RegressionModel
 
 
 def validate_power_of_2(value: List[str], ctx: typer.Context):
@@ -114,14 +113,7 @@ def validate_nearest_distance(value: int) -> int:
 
 
 def validate_estimator(value: str) -> str:
-    if value.upper() not in RegressionModel.__members__.keys():
-        raise typer.BadParameter(
-            "Invalid estimator "
-            + value
-            + " available estimators are "
-            + str(set(RegressionModel.__members__.keys()))
-        )
-    return value
+    raise Exception("Validate estimator to be implemented")
 
 
 def validate_board(value: str) -> str:
