@@ -72,10 +72,7 @@ class MyProblem(Problem):
 
     def _evaluate(self, x: List[int], out, *args, **kwargs):
         out["F"] = np.column_stack(
-            [
-                self.evaluator.fitness(tuple(x), metric)
-                for metric in self.metrics
-            ]
+            self.evaluator.fitness(tuple(x))
         )
 
     def __is_power_of_2(self, n) -> int:
